@@ -9,6 +9,7 @@ import nose
 from fabric.api import *
 
 import docs, tag
+from utils import msg
 
 
 @task
@@ -31,7 +32,8 @@ def upload():
     """
     Build, register and upload to PyPI
     """
-    local('python setup.py sdist register upload')
+    with msg("Uploading to PyPI"):
+        local('python setup.py sdist register upload')
 
 
 @task
